pub type RallyFlags = RallyFlags;Expand description
Originally defined in ardupilotmega::enums::rally_flags
Aliased Type
#[repr(u8)]pub enum RallyFlags {
FavorableWind = 1,
LandImmediately = 2,
AltFrameValid = 4,
AltFrame = 24,
}Variants
FavorableWind = 1
MAVLink enum entry FAVORABLE_WIND.
Flag set when requiring favorable winds for landing.
LandImmediately = 2
MAVLink enum entry LAND_IMMEDIATELY.
Flag set when plane is to immediately descend to break altitude and land without GCS intervention. Flag not set when plane is to loiter at Rally point until commanded to land.
AltFrameValid = 4
MAVLink enum entry ALT_FRAME_VALID.
True if the following altitude frame value is valid.
AltFrame = 24
MAVLink enum entry ALT_FRAME.
2 bit value representing altitude frame. 0: absolute, 1: relative home, 2: relative origin, 3: relative terrain