LandingTarget

Type Alias LandingTarget 

pub type LandingTarget = LandingTarget;
Originally defined in common::messages::landing_target.

Aliased Type

pub struct LandingTarget {
Show 14 fields pub time_usec: u64, pub target_num: u8, pub frame: MavFrame, pub angle_x: f32, pub angle_y: f32, pub distance: f32, pub size_x: f32, pub size_y: f32, pub x: f32, pub y: f32, pub z: f32, pub q: [f32; 4], pub type_: LandingTargetType, pub position_valid: u8,
}

Fields

time_usec: u64

MAVLink field time_usec.

Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.

target_num: u8

MAVLink field target_num.

The ID of the target if multiple targets are present

frame: MavFrame

MAVLink field frame.

Coordinate frame used for following fields.

angle_x: f32

MAVLink field angle_x.

X-axis angular offset of the target from the center of the image

angle_y: f32

MAVLink field angle_y.

Y-axis angular offset of the target from the center of the image

distance: f32

MAVLink field distance.

Distance to the target from the vehicle

size_x: f32

MAVLink field size_x.

Size of target along x-axis

size_y: f32

MAVLink field size_y.

Size of target along y-axis

x: f32

MAVLink field x.

X Position of the landing target in MAV_FRAME

y: f32

MAVLink field y.

Y Position of the landing target in MAV_FRAME

z: f32

MAVLink field z.

Z Position of the landing target in MAV_FRAME

q: [f32; 4]

MAVLink field q.

Quaternion of landing target orientation (w, x, y, z order, zero-rotation is 1, 0, 0, 0)

type_: LandingTargetType

MAVLink field type.

Type of landing target

position_valid: u8

MAVLink field position_valid.

Boolean indicating whether the position fields (x, y, z, q, type) contain valid target position information (valid: 1, invalid: 0). Default is 0 (invalid).