pub struct CommandAck {
pub command: MavCmd,
pub result: MavResult,
pub progress: u8,
pub result_param2: i32,
pub target_system: u8,
pub target_component: u8,
}Expand description
MAVLink COMMAND_ACK message.
The minimum supported MAVLink version is MAVLink 1.
Description
Report status of a command. Includes feedback whether the command was executed. The command microservice is documented at https://mavlink.io/en/services/command.html
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
CommandAck (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
command: MavCmdMAVLink field command.
Command ID (of acknowledged command).
result: MavResultMAVLink field result.
Result of command.
progress: u8MAVLink field progress.
The progress percentage when result is MAV_RESULT_IN_PROGRESS. Values: [0-100], or UINT8_MAX if the progress is unknown.
result_param2: i32MAVLink field result_param2.
Additional result information. Can be set with a command-specific enum containing command-specific error reasons for why the command might be denied. If used, the associated enum must be documented in the corresponding MAV_CMD (this enum should have a 0 value to indicate “unused” or “unknown”).
target_system: u8MAVLink field target_system.
System ID of the target recipient. This is the ID of the system that sent the command for which this COMMAND_ACK is an acknowledgement.
target_component: u8MAVLink field target_component.
Component ID of the target recipient. This is the ID of the system that sent the command for which this COMMAND_ACK is an acknowledgement.
Implementations
Sourceimpl CommandAck
impl CommandAck
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.