pub struct SecureCommand {
pub target_system: u8,
pub target_component: u8,
pub sequence: u32,
pub operation: SecureCommandOp,
pub data_length: u8,
pub sig_length: u8,
pub data: [u8; 220],
}Expand description
MAVLink SECURE_COMMAND message.
The minimum supported MAVLink version is MAVLink 2.
Description
Send a secure command. Data should be signed with a private key corresponding with a public key known to the recipient. Signature should be over the concatenation of the sequence number (little-endian format), the operation (little-endian format) the data and the session key. For SECURE_COMMAND_GET_SESSION_KEY the session key should be zero length. The data array consists of the data followed by the signature. The sum of the data_length and the sig_length cannot be more than 220. The format of the data is command specific.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
SecureCommand (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
target_system: u8MAVLink field target_system.
System ID.
target_component: u8MAVLink field target_component.
Component ID.
sequence: u32MAVLink field sequence.
Sequence ID for tagging reply.
operation: SecureCommandOpMAVLink field operation.
Operation being requested.
data_length: u8MAVLink field data_length.
Data length.
sig_length: u8MAVLink field sig_length.
Signature length.
data: [u8; 220]MAVLink field data.
Signed data.
Implementations
Sourceimpl SecureCommand
impl SecureCommand
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.