pub struct GimbalDeviceErrorFlags(/* private fields */);Expand description
MAVLink bitmask enum GIMBAL_DEVICE_ERROR_FLAGS for common dialect.
Gimbal device (low level) error flags (bitmap, 0 means no error)
Implementations
Sourceimpl GimbalDeviceErrorFlags
impl GimbalDeviceErrorFlags
Sourcepub const AT_ROLL_LIMIT: GimbalDeviceErrorFlags
pub const AT_ROLL_LIMIT: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_AT_ROLL_LIMIT flag.
Gimbal device is limited by hardware roll limit.
Sourcepub const AT_PITCH_LIMIT: GimbalDeviceErrorFlags
pub const AT_PITCH_LIMIT: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_AT_PITCH_LIMIT flag.
Gimbal device is limited by hardware pitch limit.
Sourcepub const AT_YAW_LIMIT: GimbalDeviceErrorFlags
pub const AT_YAW_LIMIT: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_AT_YAW_LIMIT flag.
Gimbal device is limited by hardware yaw limit.
Sourcepub const ENCODER_ERROR: GimbalDeviceErrorFlags
pub const ENCODER_ERROR: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_ENCODER_ERROR flag.
There is an error with the gimbal encoders.
Sourcepub const POWER_ERROR: GimbalDeviceErrorFlags
pub const POWER_ERROR: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_POWER_ERROR flag.
There is an error with the gimbal power source.
Sourcepub const MOTOR_ERROR: GimbalDeviceErrorFlags
pub const MOTOR_ERROR: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_MOTOR_ERROR flag.
There is an error with the gimbal motors.
Sourcepub const SOFTWARE_ERROR: GimbalDeviceErrorFlags
pub const SOFTWARE_ERROR: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_SOFTWARE_ERROR flag.
There is an error with the gimbal’s software.
Sourcepub const COMMS_ERROR: GimbalDeviceErrorFlags
pub const COMMS_ERROR: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_COMMS_ERROR flag.
There is an error with the gimbal’s communication.
Sourcepub const CALIBRATION_RUNNING: GimbalDeviceErrorFlags
pub const CALIBRATION_RUNNING: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_CALIBRATION_RUNNING flag.
Gimbal device is currently calibrating.
Sourcepub const NO_MANAGER: GimbalDeviceErrorFlags
pub const NO_MANAGER: GimbalDeviceErrorFlags
GIMBAL_DEVICE_ERROR_FLAGS_NO_MANAGER flag.
Gimbal device is not assigned to a gimbal manager.
Sourceimpl GimbalDeviceErrorFlags
impl GimbalDeviceErrorFlags
Sourcepub const fn empty() -> GimbalDeviceErrorFlags
pub const fn empty() -> GimbalDeviceErrorFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> GimbalDeviceErrorFlags
pub const fn all() -> GimbalDeviceErrorFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<GimbalDeviceErrorFlags>
pub const fn from_bits(bits: u16) -> Option<GimbalDeviceErrorFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> GimbalDeviceErrorFlags
pub const fn from_bits_truncate(bits: u16) -> GimbalDeviceErrorFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> GimbalDeviceErrorFlags
pub const fn from_bits_retain(bits: u16) -> GimbalDeviceErrorFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<GimbalDeviceErrorFlags>
pub fn from_name(name: &str) -> Option<GimbalDeviceErrorFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: GimbalDeviceErrorFlags) -> bool
pub const fn intersects(&self, other: GimbalDeviceErrorFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: GimbalDeviceErrorFlags) -> bool
pub const fn contains(&self, other: GimbalDeviceErrorFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: GimbalDeviceErrorFlags)
pub fn insert(&mut self, other: GimbalDeviceErrorFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: GimbalDeviceErrorFlags)
pub fn remove(&mut self, other: GimbalDeviceErrorFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: GimbalDeviceErrorFlags)
pub fn toggle(&mut self, other: GimbalDeviceErrorFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: GimbalDeviceErrorFlags, value: bool)
pub fn set(&mut self, other: GimbalDeviceErrorFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: GimbalDeviceErrorFlags,
) -> GimbalDeviceErrorFlags
pub const fn intersection( self, other: GimbalDeviceErrorFlags, ) -> GimbalDeviceErrorFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: GimbalDeviceErrorFlags,
) -> GimbalDeviceErrorFlags
pub const fn union( self, other: GimbalDeviceErrorFlags, ) -> GimbalDeviceErrorFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: GimbalDeviceErrorFlags,
) -> GimbalDeviceErrorFlags
pub const fn difference( self, other: GimbalDeviceErrorFlags, ) -> GimbalDeviceErrorFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: GimbalDeviceErrorFlags,
) -> GimbalDeviceErrorFlags
pub const fn symmetric_difference( self, other: GimbalDeviceErrorFlags, ) -> GimbalDeviceErrorFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> GimbalDeviceErrorFlags
pub const fn complement(self) -> GimbalDeviceErrorFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl GimbalDeviceErrorFlags
impl GimbalDeviceErrorFlags
Sourcepub const fn iter(&self) -> Iter<GimbalDeviceErrorFlags> ⓘ
pub const fn iter(&self) -> Iter<GimbalDeviceErrorFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GimbalDeviceErrorFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<GimbalDeviceErrorFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.