MavDoRepositionFlags

Struct MavDoRepositionFlags 

pub struct MavDoRepositionFlags(/* private fields */);
MAVLink bitmask enum MAV_DO_REPOSITION_FLAGS for common dialect.

Bitmap of options for the MAV_CMD_DO_REPOSITION

Implementations

Source

impl MavDoRepositionFlags

pub const CHANGE_MODE: MavDoRepositionFlags

MAV_DO_REPOSITION_FLAGS_CHANGE_MODE flag.

The aircraft should immediately transition into guided. This should not be set for follow me applications

Source

impl MavDoRepositionFlags

pub const fn empty() -> MavDoRepositionFlags

Get a flags value with all bits unset.

pub const fn all() -> MavDoRepositionFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<MavDoRepositionFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> MavDoRepositionFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> MavDoRepositionFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<MavDoRepositionFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: MavDoRepositionFlags) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: MavDoRepositionFlags) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: MavDoRepositionFlags)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: MavDoRepositionFlags)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: MavDoRepositionFlags)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: MavDoRepositionFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection( self, other: MavDoRepositionFlags, ) -> MavDoRepositionFlags

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: MavDoRepositionFlags) -> MavDoRepositionFlags

The bitwise or (|) of the bits in self and other.

pub const fn difference( self, other: MavDoRepositionFlags, ) -> MavDoRepositionFlags

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: MavDoRepositionFlags, ) -> MavDoRepositionFlags

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> MavDoRepositionFlags

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl MavDoRepositionFlags

pub const fn iter(&self) -> Iter<MavDoRepositionFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<MavDoRepositionFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.