pub struct MessageInterval {
pub message_id: u16,
pub interval_us: i32,
}Expand description
MAVLink MESSAGE_INTERVAL message.
The minimum supported MAVLink version is MAVLink 1.
Description
The interval between messages for a particular MAVLink message ID. This message is sent in response to the MAV_CMD_REQUEST_MESSAGE command with param1=244 (this message) and param2=message_id (the id of the message for which the interval is required). It may also be sent in response to MAV_CMD_GET_MESSAGE_INTERVAL. This interface replaces DATA_STREAM.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
MessageInterval (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
message_id: u16MAVLink field message_id.
The ID of the requested MAVLink message. v1.0 is limited to 254 messages.
interval_us: i32MAVLink field interval_us.
The interval between two messages. A value of -1 indicates this stream is disabled, 0 indicates it is not available, > 0 indicates the interval at which it is sent.
Implementations
Sourceimpl MessageInterval
impl MessageInterval
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.