pub struct LocalPositionNedCov {
pub time_usec: u64,
pub estimator_type: MavEstimatorType,
pub x: f32,
pub y: f32,
pub z: f32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub ax: f32,
pub ay: f32,
pub az: f32,
pub covariance: [f32; 45],
}Expand description
MAVLink LOCAL_POSITION_NED_COV message.
The minimum supported MAVLink version is MAVLink 1.
Description
The filtered local position (e.g. fused computer vision and accelerometers). Coordinate frame is right-handed, Z-axis down (aeronautical frame, NED / north-east-down convention)
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
LocalPositionNedCov (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
estimator_type: MavEstimatorTypeMAVLink field estimator_type.
Class id of the estimator this estimate originated from.
x: f32MAVLink field x.
X Position
y: f32MAVLink field y.
Y Position
z: f32MAVLink field z.
Z Position
vx: f32MAVLink field vx.
X Speed
vy: f32MAVLink field vy.
Y Speed
vz: f32MAVLink field vz.
Z Speed
ax: f32MAVLink field ax.
X Acceleration
ay: f32MAVLink field ay.
Y Acceleration
az: f32MAVLink field az.
Z Acceleration
covariance: [f32; 45]MAVLink field covariance.
Row-major representation of position, velocity and acceleration 9x9 cross-covariance matrix upper right triangle (states: x, y, z, vx, vy, vz, ax, ay, az; first nine entries are the first ROW, next eight entries are the second row, etc.). If unknown, assign NaN value to first element in the array.
Implementations
Sourceimpl LocalPositionNedCov
impl LocalPositionNedCov
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.