pub struct TerrainCheck {
pub lat: i32,
pub lon: i32,
}Expand description
MAVLink TERRAIN_CHECK message.
The minimum supported MAVLink version is MAVLink 1.
Description
Request that the vehicle report terrain height at the given location (expected response is a TERRAIN_REPORT). Used by GCS to check if vehicle has all terrain data needed for a mission.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
TerrainCheck (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
lat: i32MAVLink field lat.
Latitude
lon: i32MAVLink field lon.
Longitude
Implementations
Sourceimpl TerrainCheck
impl TerrainCheck
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.