MavSTX

Enum MavSTX 

pub enum MavSTX {
    V1,
    V2,
    Unknown(u8),
}
mavio Packet start marker.

Protocol-specific start-of-text (STX) marker used to indicate the beginning of a new packet.

Any system that does not understand protocol version will skip the packet.

See:

Variants



V1

Designates MAVLink 1 protocol, equals to STX_V1.



V2

Designates MAVLink 2 protocol, equals to STX_V2.



Unknown(u8)

Unknown protocol.

Implementations

Source

impl MavSTX

pub fn is_magic_byte(value: u8) -> bool

Checks that value represents MAVLink magic (start-of-text) byte.

Attempt to convert MavSTX into MavLinkVersion. Otherwise, returns None.