SignStrategy

Enum SignStrategy 

pub enum SignStrategy {
    Sign,
    ReSign,
    Strict,
    Proxy,
    Strip,
}
serde | specta Message signing strategy.

Defines how message signing will be applied.

By default, the SignStrategy::Sign strategy will be applied.

Variants



Sign

Apply message signing for all messages. Sign unsigned messages.

Unsigned messages will be signed. Messages with incorrect signature will be rejected.

For messages with unknown links the main link_id and key will be used for validation.

When set as a strategy for unknown_links, then valid messages with unknown links will keep their signature for ReSign outgoing / incoming strategies.

Versionless frames of MAVLink 1 protocol will be passed without change.



ReSign

Enforce message signing for all messages. Re-sign messages with correct signing using the main link_id and key.

Unsigned messages will be signed. Messages with incorrect signature will be rejected.

For messages with unknown links the main link_id and key will be used for validation.

When set as a strategy for unknown_links, then valid messages with unknown links will be re-signed for both Sign and ReSign outgoing / incoming strategies using the main link_id and key.

Versionless frames of MAVLink 1 protocol will be passed without change.



Strict

Apply message signing for all messages. Reject messages without signing or with incorrect signatures.

Unsigned messages will be rejected. Messages with incorrect signature will be rejected.

Messages with unknown links will be rejected.

When set as a strategy for unknown_links, then messages with unknown links (even when valid) will be considered invalid for Sign and ReSign incoming / outgoing strategies.

Versionless frames of MAVLink 1 protocol will be rejected.



Proxy

Pass messages as they are.



Strip

Strip any signing information from messages.