pub struct ParamValueArray {
pub param_count: u16,
pub param_index_first: u16,
pub param_array_len: u8,
pub flags: u16,
pub packet_buf: [u8; 248],
}Expand description
MAVLink PARAM_VALUE_ARRAY message.
The minimum supported MAVLink version is MAVLink 2.
Description
Parameter multi param value container.
Encoding/Decoding
Message encoding/decoding are provided by implementing core::convert::TryFrom<Payload> for
ParamValueArray (encoding) and [IntoPayload] (decoding) traits.
These traits are implemented by Message proc macro.
Fields
param_count: u16MAVLink field param_count.
Total number of onboard parameters.
param_index_first: u16MAVLink field param_index_first.
Index of the first onboard parameter in this array.
param_array_len: u8MAVLink field param_array_len.
Number of onboard parameters in this array.
flags: u16MAVLink field flags.
Flags.
packet_buf: [u8; 248]MAVLink field packet_buf.
Parameters buffer. Contains a series of variable length parameter blocks, one per parameter, with format as specified elsewhere.
Implementations
Sourceimpl ParamValueArray
impl ParamValueArray
Sourcepub const fn spec() -> MessageInfo
pub const fn spec() -> MessageInfo
Returns specification for this message.
Sourcepub const fn message_id() -> u32
pub const fn message_id() -> u32
Message ID.
Sourcepub const fn min_supported_mavlink_version() -> MavLinkVersion
pub const fn min_supported_mavlink_version() -> MavLinkVersion
Minimum supported MAVLink version for this message.