pub type LandingTarget = LandingTarget;Expand description
Originally defined in common::messages::landing_target.
Aliased Type
pub struct LandingTarget {}Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
target_num: u8MAVLink field target_num.
The ID of the target if multiple targets are present
frame: MavFrameMAVLink field frame.
Coordinate frame used for following fields.
angle_x: f32MAVLink field angle_x.
X-axis angular offset of the target from the center of the image
angle_y: f32MAVLink field angle_y.
Y-axis angular offset of the target from the center of the image
distance: f32MAVLink field distance.
Distance to the target from the vehicle
size_x: f32MAVLink field size_x.
Size of target along x-axis
size_y: f32MAVLink field size_y.
Size of target along y-axis
x: f32MAVLink field x.
X Position of the landing target in MAV_FRAME
y: f32MAVLink field y.
Y Position of the landing target in MAV_FRAME
z: f32MAVLink field z.
Z Position of the landing target in MAV_FRAME
q: [f32; 4]MAVLink field q.
Quaternion of landing target orientation (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
type_: LandingTargetTypeMAVLink field type.
Type of landing target
position_valid: u8MAVLink field position_valid.
Boolean indicating whether the position fields (x, y, z, q, type) contain valid target position information (valid: 1, invalid: 0). Default is 0 (invalid).