#[repr(u8)]pub enum PreflightStorageParameterAction {
ParamReadPersistent = 0,
ParamWritePersistent = 1,
ParamResetConfigDefault = 2,
ParamResetSensorDefault = 3,
ParamResetAllDefault = 4,
}Expand description
MAVLink enum PREFLIGHT_STORAGE_PARAMETER_ACTION for common dialect.
Actions for reading/writing parameters between persistent and volatile storage when using MAV_CMD_PREFLIGHT_STORAGE. (Commonly parameters are loaded from persistent storage (flash/EEPROM) into volatile storage (RAM) on startup and written back when they are changed.)
Variants
ParamReadPersistent = 0
MAVLink enum entry PARAM_READ_PERSISTENT.
Read all parameters from persistent storage. Replaces values in volatile storage.
ParamWritePersistent = 1
MAVLink enum entry PARAM_WRITE_PERSISTENT.
Write all parameter values to persistent storage (flash/EEPROM)
ParamResetConfigDefault = 2
MAVLink enum entry PARAM_RESET_CONFIG_DEFAULT.
Reset all user configurable parameters to their default value (including airframe selection, sensor calibration data, safety settings, and so on). Does not reset values that contain operation counters and vehicle computed statistics.
ParamResetSensorDefault = 3
MAVLink enum entry PARAM_RESET_SENSOR_DEFAULT.
Reset only sensor calibration parameters to factory defaults (or firmware default if not available)
ParamResetAllDefault = 4
MAVLink enum entry PARAM_RESET_ALL_DEFAULT.
Reset all parameters, including operation counters, to default values
Implementations
Sourceimpl PreflightStorageParameterAction
impl PreflightStorageParameterAction
Sourcepub fn entries() -> impl Iterator<Item = PreflightStorageParameterAction>
pub fn entries() -> impl Iterator<Item = PreflightStorageParameterAction>
Iterator over all entries within this enum.
Requires metadata feature flag to be enabled.