pub enum MavSTX {
V1,
V2,
Unknown(u8),
}Expand description
mavio
Packet start marker.
Protocol-specific start-of-text (STX) marker used to indicate the beginning of a new packet.
Any system that does not understand protocol version will skip the packet.
See:
Variants
V1
Designates MAVLink 1 protocol, equals to STX_V1.
V2
Designates MAVLink 2 protocol, equals to STX_V2.
Unknown(u8)
Unknown protocol.
Implementations
Sourceimpl MavSTX
impl MavSTX
Sourcepub fn is_magic_byte(value: u8) -> bool
pub fn is_magic_byte(value: u8) -> bool
Checks that value represents MAVLink magic (start-of-text) byte.
Sourcepub fn to_mavlink_version(&self) -> Option<MavLinkVersion>
pub fn to_mavlink_version(&self) -> Option<MavLinkVersion>
Attempt to convert MavSTX into MavLinkVersion. Otherwise, returns None.